package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"(```````!``````````)"Q````
M`````````$``.``+`$``'P`>``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````("@````````@*``````````
M$`````````$````&````H*L```````"@NP```````*"[````````D`0`````
M```(!0`````````0`````````@````8```#(JP```````,B[````````R+L`
M```````@`@```````"`"````````"``````````$````!````,@"````````
MR`(```````#(`@```````"``````````(``````````(``````````0````$
M````Z`(```````#H`@```````.@"````````1`````````!$``````````0`
M````````4^5T9`0```#(`@```````,@"````````R`(````````@````````
M`"``````````"`````````!0Y71D!`````29````````!)D````````$F0``
M``````P!````````#`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"@JP```````*"[````````H+L```````!@!````````&`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(```````0````0````
M!0```$=.50`"@`#`!`````$`````````!````!`````!````1TY5```````#
M`````@`````````$````%`````,```!'3E4`"WHMA#]BF@';&/4@!4GL-E_,
M#'\`````0P```&$``````````````%<````F````)P````8`````````30``
M```````]````5````#8````D````5@```%(````O````.0``````````````
M7P``````````````(P```"4```!*````'````$\````6````3@```$L`````
M`````````%D`````````/@```#@```!<`````````$D````N`````````#H`
M````````,0```%T````8````(0```%H`````````10```$P````#````````
M`%L````W````!0```#P`````````1````%4```!1````4P````T````_````
M+````"L```!!`````````%@`````````````````````````````````````
M```````````````)````0@`````````````````````````(````1P``````
M```.````$@```%X````4```````````````````````````````;````"@``
M`!H```````````````````!&``````````````````````````<````3````
M!``````````J`````````$@````M````#P```!T````B````%P```"D````?
M````#````"`````1````,````!X```!``````````#0```!0`````````"@`
M``!@```````````````U```````````````!```````````````5````````
M```````R````.P```!````!#```````````````S````&0````L`````````
M`````````````````````````````````````````````````@```!$````_
M````!`````@````@'!``!4`$AB@"0`20A@"$@HD`(DD@!`BX@A%)N@`&"@``
M```_````0@```$4```!&````3P```%````!2`````````%8```!7````6```
M`%L```!=````7P``````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.
MV7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\LNN.2?/+;TQWZH6Q@F4_#FVL)0]9F
MK\QFQ;F<0#CRBQS$B0600D75[(D'<-,S8MOM%8PES`PZEPM6I)N6I]VC:WZI
MG)O19<YMX*<""FL:GE`*BA!7H^#[20``````````````````````````````
M```````/`@``$@````````````````````````#<````$@``````````````
M``````````"#````$@````````````````````````!5`0``$@``````````
M```````````````C`@``$@````````````````````````#=`0``$@``````
M``````````````````#R````$@`````````````````````````=````(```
M``````````````````````"U`@``$@````````````````````````#K`@``
M$@````````````````````````"<`0``$@`````````````````````````'
M`@``$@````````````````````````!L`0``$@``````````````````````
M```C`0``$@`````````````````````````3`0``$@``````````````````
M``````#Y`0``$@`````````````````````````S`@``$@``````````````
M```````````%`0``$@````````````````````````"H`0``$@``````````
M``````````````"2`P``$@`````````````````````````!````(```````
M``````````````````!S`0``$@````````````````````````#A````$@``
M```````````````````````Y`@``$@`````````````````````````L````
M(`````````````````````````!^`@``$@````````````````````````"%
M`@``$@````````````````````````"5`@``$@``````````````````````
M``!&````$@````````````````````````!%`0``$@``````````````````
M``````!C````$@````````````````````````#`````$@``````````````
M``````````!T````$@````````````````````````!U`@``$@``````````
M``````````````#R`0``$@````````````````````````"D````$@``````
M``````````````````"Z`@``$@````````````````````````"O`0``$@``
M``````````````````````"A`0``$@`````````````````````````W`0``
M$@````````````````````````"D`@``$@````````````````````````!`
M`@``$@````````````````````````#F````$@``````````````````````
M``##`@``$@````````````````````````#K`0``$@``````````````````
M`````````@``$@````````````````````````!]`@``$@``````````````
M```````````<`@``$@````````````````````````"W`0``$@``````````
M``````````````"/````$@````````````````````````!@`0``$@``````
M``````````````````"-`@``$@`````````````````````````J`@``$@``
M``````````````````````!9`@``$@````````````````````````#4`@``
M$@````````````````````````!'`@``$@`````````````````````````L
M`0``$@````````````````````````!4````$@``````````````````````
M``#+`0``$@````````````````````````!N`@``$@``````````````````
M``````!/`@``$@````````````````````````#;`@``$@``````````````
M``````````";`P``$@`0`+`]````````4P````````#P`P``$@`0```T````
M````'0<```````#8`0``$@`0`'`@````````,@(````````2`P``$@`0`(`L
M````````!0`````````P`P``$@`0`"`[````````C0(````````6!```$@`0
M`)`L````````&@(```````#6`P``$``<`$#````````````````````C`P``
M$@`0`+`N````````(@````````!&`P``$@`0`,`P````````70````````"G
M`P``$0`2`(A8````````!`````````##`P``$@`0`(!4````````D@$`````
M``#.`P``$@`0`#`K````````,`````````#K`P``$``<`*C`````````````
M``````!^`0``$0`7`+"[````````$P`````````$!```$@`0`#`S````````
MS@`````````M!```$@`0`"`Q````````L@````````"V`P``$``:``#`````
M``````````````!J`P``$@`0`.`N````````1`````````#A`@``$0`<`$C`
M````````"`````````!G`@``$0`<`&#`````````"`````````#B`@``(0`<
M`$C`````````"`````````#]`P``$``;`##````````````````````C!```
M$0`:`"#`````````"`````````"\`P``$@`0`+`B````````(@````````#B
M`P``$@`0`"!4````````5`````````"X`P``(``:``#`````````````````
M``#1````$0`<`$#`````````!`````````#C`@``(0`<`$C`````````"```
M``````"``P``$@`0```S````````)`````````"-`0``(@``````````````
M``````````!4`P``$@`0`+`K````````P0````````!V`P``$@`0`"!6````
M````,P(```````"S````$0`<`(#``````````0`````````U!```$@`0`#`O
M````````A@$`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?
M9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``7U]C>&%?9FEN86QI>F4`<F5A9`!S=')C:'(`9V5T<&ED`&UE;6UO
M=F4`<'1H<F5A9%]G971S<&5C:69I8P!?7VQI8F-?<W1A<G1?;6%I;@!?7V9P
M<FEN=&9?8VAK`'-T<F-M<`!O<&5N-C0`=6YL:6YK`'-T<G1O:P!S=')N8VUP
M`%]?<W1P8W!Y7V-H:P!G971U:60`;65M8VAR`&-L;W-E9&ER`')M9&ER`'-T
M<FQE;@!S=')D=7``<F5A;&QO8P!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!S
M=&1E<G(`;65M8W!Y`'-T<G)C:'(`;'-T870V-`!O<&5N9&ER`&QS965K-C0`
M7U]V9G!R:6YT9E]C:&L`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`')E861L:6YK
M`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV:7)O;@!?7W)E
M9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS
M7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`
M7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?
M<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T
M`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,BXU
M`$=,24)#7S(N,RXT`"]U<W(O;&EB+W!E<FPU+S4N,C8N,2]X.#9?-C0M;&EN
M=7@M=&AR96%D+6UU;'1I+T-/4D4````"``$``0`!``,``@`!``$``P`$``,`
M`P`#``$``0`#``,``0`#``,``0`!``,``P`!``4``P`"``$``0`!``$``0`#
M``,``0`#``,``P`!``,``P`!``8``P`#``4``P`'``$``0`#``,``@`#``,`
M`0`!``<`"``#``,``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``P`#``,``0`!``$``0`!``$``P`!``,``0`!``$``0`!``<`"`,``!``
M````````E)&6!@``"`!"!```$````+21E@8```<`300``!`````4:6D-```&
M`%@$```0````LY&6!@``!0!B!```$````'(9:0D```0`;00``!````!U&FD)
M```#`'D$```0````=!EI"0```@"%!````````*"[````````"`````````"P
M(P```````*B[````````"`````````!P(P````````C`````````"```````
M```(P````````"#`````````"`````````"`6P```````"C`````````"```
M``````!@6````````+B_````````!@````<``````````````,"_````````
M!@````@``````````````,B_````````!@```!4``````````````-"_````
M````!@```!D``````````````-B_````````!@```%P``````````````."_
M````````!@```!X``````````````.B_````````!@```!\`````````````
M`/"_````````!@```#L``````````````+"[````````!0```$P`````````
M`````$#`````````!0```%D``````````````$C`````````!0```%$`````
M`````````&#`````````!0```%(``````````````(#`````````!0```%\`
M``````````````"^````````!P````$```````````````B^````````!P``
M``(``````````````!"^````````!P````,``````````````!B^````````
M!P````0``````````````""^````````!P````4``````````````"B^````
M````!P````8``````````````#"^````````!P````D``````````````#B^
M````````!P````H``````````````$"^````````!P````L`````````````
M`$B^````````!P````P``````````````%"^````````!P````T`````````
M`````%B^````````!P````X``````````````&"^````````!P````\`````
M`````````&B^````````!P```!```````````````'"^````````!P```!$`
M`````````````'B^````````!P```!(``````````````("^````````!P``
M`!,``````````````(B^````````!P```!0``````````````)"^````````
M!P```!8``````````````)B^````````!P```!<``````````````*"^````
M````!P```!@``````````````*B^````````!P```!H``````````````+"^
M````````!P```!L``````````````+B^````````!P```!P`````````````
M`,"^````````!P```!T``````````````,B^````````!P```"``````````
M`````-"^````````!P```"$``````````````-B^````````!P```"(`````
M`````````."^````````!P```",``````````````.B^````````!P```"0`
M`````````````/"^````````!P```"4``````````````/B^````````!P``
M`"8```````````````"_````````!P```"<```````````````B_````````
M!P```"@``````````````!"_````````!P```"D``````````````!B_````
M````!P```"H``````````````""_````````!P```"L``````````````"B_
M````````!P```"P``````````````#"_````````!P```"T`````````````
M`#B_````````!P```"X``````````````$"_````````!P```"\`````````
M`````$B_````````!P```#```````````````%"_````````!P```#$`````
M`````````%B_````````!P```#(``````````````&"_````````!P```#,`
M`````````````&B_````````!P```#0``````````````'"_````````!P``
M`#4``````````````'B_````````!P```#8``````````````("_````````
M!P```#<``````````````(B_````````!P```#@``````````````)"_````
M````!P```#D``````````````)B_````````!P```#H``````````````*"_
M````````!P```#P``````````````*B_````````!P```#T`````````````
M`+"_````````!P```#X``````````````$B#[`A(BP7UH@``2(7`=`+_T$B#
MQ`C#````````````_S4*H0``_R4,H0``#Q]``/\E"J$``&@`````Z>#_____
M)0*A``!H`0```.G0_____R7ZH```:`(```#IP/____\E\J```&@#````Z;#_
M____)>J@``!H!````.F@_____R7BH```:`4```#ID/____\EVJ```&@&````
MZ8#_____)=*@``!H!P```.EP_____R7*H```:`@```#I8/____\EPJ```&@)
M````Z5#_____);J@``!H"@```.E`_____R6RH```:`L```#I,/____\EJJ``
M`&@,````Z2#_____):*@``!H#0```.D0_____R6:H```:`X```#I`/____\E
MDJ```&@/````Z?#^____)8J@``!H$````.G@_O___R6"H```:!$```#IT/[_
M__\E>J```&@2````Z<#^____)7*@``!H$P```.FP_O___R5JH```:!0```#I
MH/[___\E8J```&@5````Z9#^____)5J@``!H%@```.F`_O___R52H```:!<`
M``#I</[___\E2J```&@8````Z6#^____)4*@``!H&0```.E0_O___R4ZH```
M:!H```#I0/[___\E,J```&@;````Z3#^____)2J@``!H'````.D@_O___R4B
MH```:!T```#I$/[___\E&J```&@>````Z0#^____)1*@``!H'P```.GP_?__
M_R4*H```:"````#IX/W___\E`J```&@A````Z=#]____)?J?``!H(@```.G`
M_?___R7RGP``:",```#IL/W___\EZI\``&@D````Z:#]____)>*?``!H)0``
M`.F0_?___R7:GP``:"8```#I@/W___\ETI\``&@G````Z7#]____)<J?``!H
M*````.E@_?___R7"GP``:"D```#I4/W___\ENI\``&@J````Z4#]____);*?
M``!H*P```.DP_?___R6JGP``:"P```#I(/W___\EHI\``&@M````Z1#]____
M)9J?``!H+@```.D`_?___R62GP``:"\```#I\/S___\EBI\``&@P````Z>#\
M____)8*?``!H,0```.G0_/___R5ZGP``:#(```#IP/S___\E<I\``&@S````
MZ;#\____)6J?``!H-````.F@_/___R5BGP``:#4```#ID/S___\E6I\``&@V
M````Z8#\____)7*?``!FD```````````55-(@^PXB7PD'$B)="002(U\)!Q(
MB50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z'C___](BS4)GP``2(L]
M,I\``$B)\NBP-P``@#V[GP```'4OZ$3]__](A<!(B07*GP``#X2\`0``2(G'
MZ*S]__^+/5:?``#HH?[__\:`T0@```"+/42?``#HC_[__X"(J@0```*+/3*?
M``#H??[__X"(J@0```&+1"0<C7@$C5@#2+C_________'TAC_T@YQP^'(`$`
M`$C!YP/H;?[__TB+?"002(T-(3D``$2+1"0<2(D%/9\``$B+%TB)2`A(C0T*
M.0``08/X`4B)2!A(B1!(BQ6EG@``2(E0$`^.RP```$B#QPA!@\`#O@0```!F
M#Q]$``!(BP](8]:#Q@%(@\<(1#G&2(D,T'7J2&/V2,'F`TB+/>2>``!(QP0P
M`````$B--94)``!%,<!(B<&)VNA(^___A<!T9DB+/;V>``!(C5PD).@3_?__
M2(T].#<``(G%2(G>,<#HP`$``$B%P'0J2(L]E)X``.CO^O__Z%K\__](BUPD
M*&1(,QPE*````(GH=6M(@\0X6UW#2(L]6IX``$B%_W0TZ'`;``#KPTB+/5>>
M``#H4OO__^N,OB````#I6____TB--4^9``!(C3UV-@``,<#H,?W__TB-/6LV
M``!(B=[H0@$``$B%P$B)QTB)!06>```/A'3____KJ.BH_/__OP$```#HKOK_
M_V8N#Q^$```````/'T``,>U)B=%>2(GB2(/D\%!413'`,<E(C3VE_?___Q4?
MG0``]&8N#Q^$```````/'T``2(T]09T``%5(C04YG0``2#GX2(GE=!E(BP7*
MG```2(7`=`U=_^!F+@\?A```````7<-F9BX/'X0```````\?`$B-/0&=``!(
MC37ZG```54@I_DB)Y4C!_@-(B?!(P>@_2`'&2-'^=!A(BP6!G```2(7`=`Q=
M_^!F#Q^$``````!=PV9F+@\?A```````#Q\`@#T*G0```'4O2(,]5YP```!5
M2(GE=`Q(BSUZG```Z,W\___H2/___\8%XIP```%=PP\?@`````#SPV8/'T0`
M`%5(B>5=Z6;___]F#Q]$``!!5T%6055!5%532(/L"$B%_P^$L0```$R+/6J<
M``!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D3(G]
M#Q^``````$R)XDR)]DB)W^AB^?__A<!U!T*`/",]=$=(@\4(2(M=`$B%VW7:
M2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$/#UU
M[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/'T``
M55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^@#____
M2(7`=#9(8U0D!$B+!7J;``!(C0302(M0"$B%TDB)$'329I!(@\`(2(M0"$B%
MTDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=P^@L^O__9F8N
M#Q^$``````"005=!5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D&#'`
M,<"`/CT/E,!(`<-(B=_HV?C__TB-="0428G$2(GO,<#H5_[__TB%P`^$#@$`
M`$B)QTF)Q>BS^/__3#G@#X/B````3&-T)!1)P>8##[9%`(3`#X2M`0``/#T/
MA*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U?)H`
M`$J-?"`"Z+KW__](A<!)B08/A'L!``!(8U0D%$B+!5J:``!(C4T!2(L4T`^V
M10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`B`)U
MZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*`````^%
M$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7LZ\)F
MD$R+/<&9``!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ2(/`"$2-:@%(
M@S@`=>^-<@-(8_9(P>8#BP7'F0``A<!U6TB)]\<%MID```$```#HN?;__TB%
MP`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+HXO?__TR+1"0(2(G!
M2(D%.YD``$K'1,$(`````$2);"04Z6_^__],B?_HV/C__TB%P$B)P4B)!1.9
M``!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q[>E>____N/__
M___IV_[__^C4]___#Q]``$%7059!54%455-(@>RX````9$B+!"4H````2(F$
M)*@````QP$B%_W0(@#\`28G^=2](BX0DJ````&1(,P0E*`````^%)`$``$B!
MQ+@```!;74%<05U!7D%?PV8/'T0``.A[]O__2(7`2(G#=,1(C40D$$B-+:0P
M``!,C26<,```3(T]F#```$B)!"1(B=_H/?C__TB%P`^$M````$R-2!.Y`@``
M`$B)[TR)SO.F#Y?`'`"$P'35N0,```!,B<Y,B>?SI@^7P!P`A,!TOTR)]TR)
M3"0(Z.?U__],BTPD"$F)Q4R)S^C7]?__08U\!0)(8__H*O7__TR+3"0(28G%
M2(G'38GP3(GY2,?"_____[X!````,<#H5O?__TB+-"1,B>_HJO7__X/X_TR)
M[W00BT0D*"4`\```/0!```!T)^@-]?__3(GOZ&7U___I.____TB)W^@(]___
M3(GWZ`#U___IS/[__^B6_O__Z]?H7_;__V9F+@\?A```````#Q]``%-(B?M(
M@>R@````2(GF9$B+!"4H````2(F$))@````QP.A:]O__A<!U-HM4)!B!X@#P
M``"!^@!```!T+('Z`*```'0D2(N,))@```!D2#,,)2@```!U*$B!Q*````!;
MPS'`Z^`/'T``O@(```!(B=_HB_;__X7`#Y3`#[;`Z\7HS/7__V9F+@\?A```
M````D$%6055)B?9!5%5)B?Q32(T]`"\``+K_#P``2('L$!```$B)XTB)WF1(
MBP0E*````$B)A"0($```,<#H$?7__X7`#XZ)````C5#_1(LM;Y8``$ACZH`\
M+`!T5DACZ$B)ZKXO````2(G?Z$/S__](A<!T1D2)[^B6]?__2(GI2(G:3(GF
M2(G'Z+7T__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=05Q!74%>PV:0
MA=)UJ0\?0`!$B>_H4/7__TR)\DR)YDB)Q^B2\___Z[M$BRWIE0``Z]_HXO3_
M_V:04TB)_KH`$```2('L$!```$B)XTB)WV1(BP0E*````$B)A"0($```,<#H
M8O+__TB#Z`%(.=AW%>L8#Q^``````,8``$B#Z`%(.=AT!8`X+W3OOB\```!(
MB=_HXO/__TB%P'0U2#G8=RA(B=_H4/3__TB+C"0($```9$@S#"4H````=3Q(
M@<00$```6\,/'T``Q@``Z],/'P!(BX0D"!```&1(,P0E*````'442('$$!``
M`$B-/70M``!;Z0'T___H'/3__V9F+@\?A```````D$B#[`B+/0:5``#H4?3_
M_TB+%9J4``!(C0VK;0``2(TU4"T``$B)QTB#Q`CIL/3__TB#[`B+/=:4``#H
M(?3__TB)Q^BY____BSW#E```Z`[T__],C07$+@``2(T5D`\``$B--2DM``!%
M,<E(B<=(@\0(3(G!Z=?R__\/'X``````55-(@>PH(```9$B+!"4H````2(F$
M)!@@```QP$B)XTB-K"00$```Z!3R__],C0V]+```2(T-ZRP``$&)P+H!$```
MO@$```!(B=\QP.C?\___N@`0``!(B>Y(B=_HO_+__X7`>%.->`%(B<-(8__H
M;?'__TB%P$B)P7082&/;2(GN2(G'2(G:Z/3S__](B<'&!!@`2(N4)!@@``!D
M2#,4)2@```!(B<AU$TB!Q"@@``!;7<,/'T0``#')Z]?HS_+__V9F+@\?A```
M````#Q]``.DK____9F8N#Q^$``````!!5T%6055!5$F)]%532(G[2(T].BP`
M`$B![+@0``!D2(L$)2@```!(B80DJ!```#'`2(UT)`SH]?;__[XO````2(G?
M2(G%Z!7R__](A<!T0$B-/0,L``!(B=XQP.@O^/__2(G82(N,)*@0``!D2#,,
M)2@````/A9H!``!(@<2X$```6UU!7$%=05Y!7\,/'P!,B>?H^/'__TB--<@K
M``!(B<?H*?+__TB%P$F)QW2A08`_`$R-I"2@````3(UL)!`/A.8```!F+@\?
MA```````2(7M=!-,B?Y(B>_HX/'__X7`#X2@````3(G_Z+#P__])C50'_TF)
MQDDYUW,G@#HO=`OK(`\?0`"`.B]U#,8"`$B#Z@%).==U[TR)_^A_\/__28G&
M2(G?Z'3P__])C40&`4@]_P\```^'$____TB#[`A(C0TE+```3(T-&BL``%.Z
M`!```$V)^+X!````3(GG,<#HZ?'__TR)[DR)Y^@^\/__A<!:6740BT0D*"4`
M\```/0"```!T8$B--=@J```Q_^@Z\?__2(7`28G'#X2N_O__08`_``^%)/__
M_TB%[70?2(T]12H``+D"````2(GN\Z8/E\`<`(3`=+T/'T0``$&^`0```$R-
M/2`J``#I0O___V8/'T0``+X!````3(GGZ&OQ__^%P'6/2(T]6BH``$R)YNB(
M]O__3(GGZ(#P___I3_[__^B6\/__9@\?1```4[XO````2(G[Z.+O__](C5`!
M2(7`2`]%VDB)WUOI3O#__V9F+@\?A```````#Q\`2(7_="N`/P!T)E-(B?OH
M/>___TB#P`%(/0`0``!W(4B)WUOI6/O__P\?A```````2(T]=BD``.D$\/__
M#Q]``#'`6\-F9BX/'X0``````)!32(T]PRD``$B#[!!D2(L$)2@```!(B40D
M"#'`2(U<)`3H.O7__TB-/:<I```QP.@L]?__2(T]H2D``#'`Z![U__](C3V<
M*0``,<#H$/7__TB-/94I```QP.@"]?__2(T]ERD``#'`Z/3T__](C3T^*0``
M,<#HYO3__TB-/8<I```QP.C8]/__2(T]@RD``#'`Z,KT__](C3U_*0``,<#H
MO/3__TB-/0\I```QP.BN]/__2(T];2D``#'`2(G>Z,WS__](A<!T$4B-/4,I
M``!(B<8QP.@7]?__2(T]5RD``#'`2(G>Z*;S__](A<!T$4B-/5,I``!(B<8Q
MP.CP]/__2(T]32D``#'`2(G>Z'_S__](A<!T0DB-/90H``!(B<8QP.C)]/__
M2(TU1RD``$B-/;<H```QP.BT]/__2(M$)`AD2#,$)2@```!U-4B#Q!!;PV8/
M'T0``$B-/04I```QP$B)WN@G\___2(7`=+E(C3V3*```2(G&,<#H<?3__^NF
MZ(KN__]F+@\?A```````2(/L&$B-/6TH``!D2(L$)2@```!(B40D"#'`2(UT
M)`3HV_+__S'22(7`=!4/M@`\,`^4PH3`#Y3`"<*#\@$/MM)(BTPD"&1(,PPE
M*````(G0=05(@\08P^@C[O__#Q\`2('LV````(3`2(ET)"A(B50D,$B)3"0X
M3(E$)$!,B4PD2'0W#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD`````\I
MK"2@````#RFT)+`````/*;PDP````&1(BP0E*````$B)1"08,<!(C80DX```
M`$B)^DB)X;X!````2(L]NXX``$B)1"0(2(U$)"#'!"0(````QT0D!#````!(
MB40D$.B8[/__O_\```#H?NO__V9F+@\?A```````#Q\`0515N@(```!3,?9!
MB?Q(@>P0``$`9$B+!"4H````2(F$)`@``0`QP.BS[?__2(UH_TB)Z$C!^#](
MP>@P2(U4!0`/M])(*<)(*=4/B*0```!(B>,/'T0``#'22(GN1(GGZ'OM__](
M@_C_#X2.````N@@``0!(B=Y$B>?H$>O__X/X_P^$@P```$B82(/X!W902(U$
M`_A(.=AR1DB-%8^-``#K#@\?1```2(/H`4@YV'(O2(L*2#D(=>](*=U(`>A(
MB[0D"``!`&1(,S0E*````'5'2('$$``!`%M=05S#9I!(@>T```$`2(']``#_
M_P^%9/___TC'P/_____KPDB-/<,F```QP.@U_O__2(T]PB8``#'`Z"?^___H
M0NS__V:02(/L".AW[/__B<?H\.K__TB%P'0+2(L`2(/$",,/'P`QP.OT9F8N
M#Q^$``````"005152(G]4TB-/8(F``!(@^P09$B+!"4H````2(E$)`@QP$B-
M="0$Z&3P__](A<!T"(`X`$B)PW4O2(T]4"8``$B)[C'`Z*;Q__](BT0D"&1(
M,P0E*````'5O2(/$$%M=05S##Q]$``!(B>_HD.K__TB)WTF)Q.B%ZO__28U\
M!`+HV^G__TB#[`A,C0TW)0``2(T--B8``%-(Q\+_____2(G'28G$28GHO@$`
M```QP.C\Z___2(T]U24``$R)YC'`Z"OQ__]86NN!Z$+K__]FD$%7059!54%4
M28G]55-(C3W-)```2('L>`$``&1(BP0E*````$B)A"1H`0``,<!(C06G)0``
M3(UD)!Q(QT0D,`````!(QX0DB`````````!(QT0D4`````!(B40D($B-!2DD
M``!,B>9(B40D*$B-!08E``!(B40D8$B-!?,D``!(B40D:$B-!58E``!(B40D
M<$B-!?@D``!(B40D>$B-!48E``!(B80D@````$B-!1XE``!(B40D0$B-!2\E
M``!(B40D2#'`Z/;N__](A<!T"8`X``^%:`(``#'`Z"'^__](A<!(B<,/A*4"
M``!(B=_H/>G__TB-?``!Z)/H__^`.P!)B<9T-4R-/>HD``!,B?601`^V`TB)
M[S'`3(GY2,?"_____[X!````2(/#`4B#Q0+HJ^K__X`[`'762(U<)&!(C3TS
M)```ZQ@/'X0``````$B#PPA(BSM(A?\/A(`!```QP$R)YNA6[O__2(7`2(G%
M=-Z`.`!TV4B)Q^AQ\___A<!TS4B)[^B5Z?__2(7`28G`#X1)`0``9@\?A```
M````3(G"BPI(@\($C8'__O[^]]$AR"6`@("`=.F)P<'I$*F`@```#T3!2(U*
M`D@/1-&)P0#!3(GQ2(/:`TPIPHLQ2(/!!(V&__[^_O?6(?`E@("`@'3IB<9,
MB40D",'N$*F`@```#T3&2(UQ`D@/1,Z)QD``QDB#V0-,*?&-G`H$!```2&/;
M2(G?Z&3G__])B<=(C07.(P``059,C0VZ(@``2(T-M2,``$C'PO____]03(M$
M)!B^`0```$R)_S'`Z'[I__],B?^^P`$``.CAZ?__@_C_7T%8=1+HE.C__T2+
M"$&#^1$/A5D$``!(C;0DD````$R)_^C7Z/__A<")Q747BX0DJ````"4`\```
M/0!````/A$H!``!)BTT`2(L]GXD``$B-%?`C``!-B?B^`0```#'`,=OH9^;_
M_^F"````9I`Q[68/'T0``$ACQ4B+7,0@2(7;=#N`.P!T-DB)WX/%`>CK\?__
MA<!TWTB)W^@/Z/__2(7`28G`#X6#_O__2&/%2(M<Q"!(A=MURV8/'T0``$4Q
MP.EH_O__#Q^$``````!(B<=(B40D".CC^___2(M$)`A(B<?HQN?__TB)PP\?
M`$B+E"1H`0``9$@S%"4H````2(G8#X6>`P``2('$>`$``%M=05Q!74%>05_#
M#Q]``$B-/3DB```Q[4B%_W0F9I`QP$R)YH/%`>@3[/__2(7`=`6`.`!U*4AC
MQ4B+?,1`2(7_==R_#0```$B-'04B``#HN^7__TF)QNDH_?__#Q\`2(G'Z#CG
M__](A<!(B<,/A??\___KP68N#Q^$``````!$B[0DK````.ASY___03G&#X6@
M_O__BX0DJ````"7_`0``/<`!```/A8G^__](B=_H6^7__TB-/8\A``!(B<-,
MB>8QP.AWZ___2(7`#X1>`0``28M]`$B)QN@R]/__2(7`28G$#X1&`0``3(GG
MZ+[E__^#^`-^04ACT$B-/8@A``"Y!0```$F-=!3\\Z8/E\*`V@"$TG4A@_@$
M#X0``@``@^@$2)A!@'P$_R\/A.\!```/'X``````,<#H`?C__X7`=14Q]DR)
MY^CCY?__A<!!B<0/A>@```!(C37&(```2(T]4B```$R-)6`A```QP$R-+0,@
M``#H)>S__^CPY/__051,C0WP'P``4$B-#1PA``!(Q\+_____38GXO@$```!(
MB=\QP.BVYO__6%KK0V:0Z-OE__^#.!%U2>BQY/__@\4!2(/L"$B-#>X@``!!
M5%5-B>E038GX2,?"_____[X!````2(G?,<#H<^;__TB#Q""^P`$``$B)W^C2
MYO__@_C_=*U,B?_HE>3__TB-/4\?``!(B=XQP.B$Z___2(G?Z(SY___IM_W_
M_P\?@`````!-BV4`Z;'^__\/'X``````B<?H&?C__TB%P$F)Q0^(!?___TB-
M</9,C;0D*@$``#'21(GGZ-?E__^Z!@```$R)]D2)Y^AWX___2(/X!@^%!P$`
M`(L%YUX``#F$)"H!```/A<+^__\/MP777@``9D$Y1@0/A;#^__])C77.2(VL
M)#`!```QTD2)Y^B"Y?__NB@```!(B>Y$B>?H(N/__TB#^"@/A;(```!(C07N
M'P``QH0D6`$```!(C0VP'P``3(T-A!X``+X!````38GX4%5(Q\+_____2(G?
M,<#H4.7__UE>Z>S^__]F#Q^$``````!-BVT(387M#X0+_O__3(GOZ'OC__](
M@_@##X;Y_?__28UT!?Q(C3U#'P``N04```#SI@^7P!P`A,!-#T3EZ=;]__])
MBTT`2(L]<X4``$B-%80?``!-B?B^`0```#'`,=OH.^+__^E6_/__2(T]`A\`
M`#'`Z`CV___H(^3__P\?`$%455-(@^P0BST2A0``9$B+!"4H````2(E$)`@Q
MP.A-Y/__BSWWA```2(G#Z#_D__\/MI.X````2(U<)`1(C3VX'0``2(G>B)"Y
M````,<#H3.C__TB%P'0)@#@Q#X2N`0``,<#HI_/__XL]L80``.C\X___2(TU
ML1X``+D#````N@$```!(B<?H`^+__TB%P$B)Q70U2(M`$(L]@80``$R+(.C)
MX___2(T5@!X``$B)QTR)YN@'XO__2(M%$$B+*/9%#D`/A88!``"+/5"$``#H
MF^/__TB--5<>``"Y`P```+H!````2(G'Z*+A__](A<!(B<5T/4B-/<T<```Q
MP$B)WNB9Y___2(7`28G$#X0-`0``2(M%$(L]`X0``$B+*.A+X___3(GB2(G'
M2(GNZ(WA__^+/>>#``#H,N/__TB--?`=``"Z`0```$B)Q^B>X/__BSW(@P``
M2(G%Z!#C__](C17C'0``2(GN2(G'Z$[A__^+/:B#``#H\^+__TB-/3T<``#&
M@+D`````2(G>,<#H"^?__TB%P$B)PTB)!<Z#``!T/+[``0``2(G?Z'_C__^-
M4`&#^@%V"8/X$0^%J0```$B+1"0(9$@S!"4H````#X6R````2(/$$%M=05S#
MD$B+/9&#``#H]/;__TB%P$B)PTB)!7>#``!UJ4B-/>X=```QP.AWXO__#Q^`
M`````(!X`0`/A$_^___I0_[__Y!(BP51@P``BSWS@@``3(L@2(M%$$B+*.@T
MXO__3(GF2(GOZ!GL___IY_[__P\?0`"+/<J"``#H%>+__TB)[DB)Q^BJX?__
MZ5_^__^)P4B+!02#``!(C3V='0``2(G:2(LP,<#H^.'__^B3X?__#Q\`4S'`
M2(G[Z`7S__^%P'0*2(7;=`6`.P!U!UO##Q]$``!(B=_H"/'__TB)Q^C0\/__
M2(T]'1P``$B)QKD$````\Z8/E\`<`(3`=<](B=];Z6WI__]F+@\?A```````
M#Q\`05=!5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```Q
MP$B)X6:00XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``
M2`GP2(G62,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-
ML0`"```/'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@
M_TB)07A(.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)
MT`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)
MR$C!Z`)(P>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)
MQD2-)`9,B=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-
MM#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN
M2#'P2(V4$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G!
M[`)$C2P"2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;
M3#'P2`'03(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'1
M28V$!IEY@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD
M,$G![0)(P>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%
M2,'N&T@)\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4
M$YEY@EI(P>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`
M3`GQ2(GP2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)
M\D2-+`),B>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'9
M08G43#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&
M2#'"28V,#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$
MC3012,'F'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'0
M3(GR2,'B!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(
M28V4$YEY@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!
MXAY)P>X"3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@
M!4@)\$2-+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;
M3"':08G$3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>
M2#'P3(G!08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G!
M[0)$C30"2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(
MP>X;3#'82`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"
M3(GF2#'128V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20
M````1(T<"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),
M,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````
M2#'P3"'83XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)
MV$G!ZP))P>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,
M&:'KV6Y-B>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,
M">I-B<5%B<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,
M">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN```
M`$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G9
M28GSB?9),<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)
MP$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$
MB<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!
MT4R)VDG!ZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0P
MH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G2
M23'U2`.4).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,
MB>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;
M2,'@!4P)X(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#
M2`.,)/````!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)
MP>T"2<'@'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)
MVDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0Q
MYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$
M)``!``!,"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)
MP>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00
M`0``1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!
MX!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)
M]DP!QDV)V$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``
M1#':38GC2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!
MB<M,">I-B<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!
MX`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0Q
MX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$
M3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,
M"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,
MB=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&
M28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)
MZ4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)
M`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)
MWD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!
MY@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18
M`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-
M">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G!
M[1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS
M3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"
M2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'0
M3(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,
M(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)
M]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)
M[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>
M22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-
M)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%
M3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)
M"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%
M3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!
M``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)
M[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;
M2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+
MM"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!
MX!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)
M\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=
M30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))
MP>X"2,'B'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH
M2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),
M(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!
MZQM,"=F)R4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&
M3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GP
MOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)
MR4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!
M``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;
M20G%2(N$)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(
M2(N,)/@!``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$
M18GM13'>2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)
MSTB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5(
M"<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%
M,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!
MX!Y%B<-)"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;
M2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD
M2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&
M20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@
M!4@)R$B+C"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@Q
MP46)VT$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)
MQTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!
MX@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%
MB?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"
M2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!
MX`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,
MB?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M
M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(
MP>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ
M18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>
M08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(
MP>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!
M18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G6
M2(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;
M30G828G#2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G5
M1(GB3(E?$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I
M&T4!R$@)RDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U
M$DB!Q)@"``!;74%<05U!7D%?P^@BR___9I!(@^P(OX````#H8LG__[J)J\WO
MN?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````
M2,=`,`````#'0'@`````2(/$",-F9BX/'X0``````)!!5T%62&/"055!5$F)
MQ5532(GS28G\2(/L"$B+=RA(BU<P28UL)#B-#,9(.?%(B4\H2(/2`$C!Z!U(
M`=!(B4<P2&-_>(7_=%A!OT````!(B=Y!*?]%.?U%#T[]2`'O36/W3(GRZ$?+
M__]!BT0D>$0!^(/X0$&)1"1X=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,B>=%
M*?U,`?/H\NC__V:008/]/WY508/M0$6)[T'![P9%B?Y)@\8!2<'F!DD!WI#S
M#V\#3(GG2(/#0`\110#S#V]#T`\111#S#V]#X`\112#S#V]#\`\113#HH>C_
M_TPY\W7,0<'G!D4I_4ECQ4B#^`AR7$B+$TF)5"0X2(M4`_A(B50%^$B-50A(
M@^+X2"G52"GK2`'%2(/E^$B#_0AR%TB#Y?@QP$B+#`-(B0P"2(/`"$@YZ'+O
M18EL)'A(@\0(6UU!7$%=05Y!7\,/'T``J`1U'4B%P'3?#[83J`)!B%0D.'33
M#[=4`_YFB50%_NO'BQ-!B50D.(M4`_R)5`7\Z[9F9BX/'X0```````\?`$%6
M055,C78X05152(G]4TR+9BA(B?-,BVXP3(G@2,'H`X/@/XU(`4B8QD0&.(!(
M8\%,`?"#^3@/CYL!``"Z.````#'V*<J#^@@/@F$!``")T4C'``````!(QT0(
M^`````!(C4@(2(/A^$@IR`'"@^+X@_H(<A*#XO@QP(G'@\`(.=!(B30Y<O-,
MB>A$B&MS1(AC=TC!Z!A(B=^(0W!,B>A(P>@0B$-Q3(GH2,'H"(A#<DR)X$C!
MZ!B(0W1,B>!(P>@0B$-U3(G@2,'H"(A#=N@<Y___2(L#2(G?2,'H&(A%`$B+
M`TC!Z!"(10%(BP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%
M!4B+0PA(P>@(B$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,0
M2,'H"(A%"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!Z`B(
M10Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$422(M#
M((A%$UM=05Q!74%>Z5C&__\/'X0``````/;"!'5KA=(/A,O^___VP@+&```/
MA+_^__\QR6:)3!#^Z;/^__\/'P"Z0````"G*=`\QR8G.@\$!.='&!#``<O-(
MB=_H^.7__V8/[\`/$4,X2<=&,`````!!#Q%&$$$/$48@Z7'^__]F#Q^$````
M``#'``````#'1!#\`````.E5_O__9BX/'X0```````\?`)"0D)"0D)"0D)"0
MD)"0D)!(BPV19P``Z>3$__](@^P(2(/$",,````!``(`+BX`)7,O)7,`+W!R
M;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q
M`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`55-%
M4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E
M<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#8S`"UE`"TM````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)
M3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S
M:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`[
M"B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?
M;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H
M)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/
M5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H
M)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@
M)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N
M("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M
M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE
M(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R
M=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@
M)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M
M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@
M:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@
M,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!
M1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T
M<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<
M,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<
M,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S
M="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@
M,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F
M<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T
M87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*
M<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP
M86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@
M>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D
M=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z
M("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]
M*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M
M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D
M8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A
M9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E
M860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D
M8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE
M<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50
M871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@
M/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D
M97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O
M("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI
M('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN
M960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@
M)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S
M:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T
M*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II
M<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D
M1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE
M7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I
M>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F
M(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF
M)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N
M86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO
M)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB
M4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I
M9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``0T%#2$4``'!E<FQX<VDN8P````$;`SL(`0``(````-R#__]4`0``7(?_
M_WP!``!LA___)`8``*R)__\D`0``O(K__Y0!``",B___X`$``!R,__\,`@``
M;([__U@"``#LC___I`(``'R0___(`@``7)'__PP#```LDO__/`,``%R2__]4
M`P``K)+__VP#``!\D___F`,``(R3__^L`P``K)7__PP$``#<E?__*`0``"R6
M__],!```O)?__W`$```<F/__C`0``-R8__^D!```_)G__]P$```LFO__^`0`
M`/R:__\X!0``'*+__]`%``"LI/__!`8```RE__]4!@``'+O__Z0&``!\N___
MO`8``!R]__\@!P``:K___V0'```4``````````%Z4@`!>!`!&PP'")`!!Q`4
M````'````("(__\B```````````````4``````````%Z4@`!>!`!&PP'")`!
M```D````'````(""__^``P````X01@X82@\+=PB``#\:.RHS)"(`````%```
M`$0```#8A?__"```````````````2````%P````@B?__S`````!"#A"/`D(.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.
M$$(."$D+`"@```"H````I(G__X0`````00X0A@)!#AB#`T<.,`)S"@X800X0
M00X(00L`2````-0````(BO__3`(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=*#F`#)@$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"T@````@`0``
M#(S__W$!````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[P`7X*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A'"P`@````;`$``$"-__^$`````$$.$(,"
M2@ZP`0)3"@X000X(00M`````D`$``*R-___>`````$(.$(X"0@X8C0-%#B",
M!$$.*(8%1`XP@P93#L`@`H0*#C!!#BA!#B!"#AA"#A!"#@A#"RP```#4`0``
M2([__\0`````00X0@P)/#J`@`GH*#A!!#@A%"V(*#A!(#@A%"P```!0````$
M`@``Z([__S``````1`X09PX(`!0````<`@```(___TD`````1`X0?0X(`"@`
M```T`@``.(___\$`````00X0A@)!#AB#`T<.P$`"IPH.&$$.$$$."$8+$```
M`&`"``#<C___!0````````!<````=`(``-B/__\:`@```$(.$(\"0@X8C@-"
M#B"-!$(.*(P%1`XPA@9!#CB#!U$.\"$"9`H..$$.,$$.*$(.($(.&$(.$$(.
M"$0+`K$.^"%/#H`B90[X(4$.\"$````8````U`(``)B1__\B`````$$.$(,"
M7`X(````(````/`"``"LD?__1`````!+#A"#`EC##@A=#A"#`D,."```(```
M`!0#``#8D?__A@$```!!#A"#`DL.(`-$`0H.$$$."$<+&````#@#``!$D___
M70````!$#B`"4PH."$$+`!0```!4`P``B)/__[(`````1P[@`0```#0```!L
M`P``,)3__QX!````0@X0C`)!#AB&`T8.((,$3`ZP@`0"Q`H.($$.&$$.$$(.
M"$,+````&````*0#```8E?__)`````!$#A!8"@X(1`L``#P```#``P``+)7_
M_\X`````0@X0C`)!#AB&`T0.((,$2PXP`DP*#B!!#AA!#A!"#@A&"V$..$\.
M0&X..$$.,`"4``````0``+R5__\=!P```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M1`XPA@9!#CB#!TX.L`,#'0(.N`-6#L`#90ZX`T(.L`,##`$*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A%"P-R`0ZX`T@.P`-A#K@#00ZP`UH.N`-)#L`#00[(`T0.
MT`-=#K`#`PT!#K@#00[``U(.N`-!#K`#`#````"8!```1)S__XT"````0@X0
MC`)!#AB&`T$.((,$1`XP`](!"@X@00X800X00@X(0@L<````S`0``*">__]3
M`````$$.$(,"60H."$8+;@X(`"P```#L!```0('__S("````00X0A@)!#AB#
M`T0.4`.V`0H.&$$.$$$."$$+`````$P````<!0``L)[__PX6````0@X0CP)"
M#AB.`T8.((T$0@XHC`5$#C"&!D$..(,'1P[0!0/F%0H..$$.,$$.*$(.($(.
M&$(.$$(."$$+````%````&P%``!PM/__5`````!$#A`"3PX(8````(0%``"X
MM/__D@$```!"#A"/`D(.&(X#10X@C01"#BB,!40.,(8&00XX@P=*#D`"90H.
M.$$.,$$.*$(.($(.&$(.$$(."$<+`L$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%
M"T````#H!0``]+7__S,"````0@X0C@)"#AB-`T8.((P$00XHA@5$#C"#!@.-
M`0H.*$$.($(.&$(.$$(."$T+````````$````"P&``#^M___#@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````+`C````````<",`````````````````````````
M```````````````!`````````/T"`````````0`````````(`P```````!T`
M````````D00````````,`````````,`<````````#0````````!\6```````
M`!D`````````H+L````````;``````````@`````````&@````````"HNP``
M`````!P`````````"``````````$`````````#`#````````]?[_;P````#(
M!0````````4`````````X`\````````&`````````,@&````````"@``````
M``#&!`````````L`````````&``````````5`````````````````````P``
M``````#HO0````````(`````````*`4````````4``````````<`````````
M%P````````"8%P````````<`````````Z!4````````(`````````+`!````
M````"0`````````8`````````!X`````````"`````````#[__]O``````$`
M``@`````_O__;P````!H%0```````/___V\``````0````````#P__]O````
M`*84````````^?__;P`````%````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````R+L`````````````````````````````]AP`````
M```&'0```````!8=````````)AT````````V'0```````$8=````````5AT`
M``````!F'0```````'8=````````AAT```````"6'0```````*8=````````
MMAT```````#&'0```````-8=````````YAT```````#V'0````````8>````
M````%AX````````F'@```````#8>````````1AX```````!6'@```````&8>
M````````=AX```````"&'@```````)8>````````IAX```````"V'@``````
M`,8>````````UAX```````#F'@```````/8>````````!A\````````6'P``
M`````"8?````````-A\```````!&'P```````%8?````````9A\```````!V
M'P```````(8?````````EA\```````"F'P```````+8?````````QA\`````
M``#6'P```````.8?````````]A\````````&(````````!8@````````)B``
M```````V(````````$8@````````5B``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````(!;
M````````8%@```````!'0T,Z("A355-%($QI;G5X*2`Q,RXS+C``1T-#.B`H
M4U5312!,:6YU>"D@-RXU+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YP<F]P97)T>0`N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD
M871A`%]?<&%T8VAA8FQE7V9U;F-T:6]N7V5N=')I97,`+F)S<P`N8V]M;65N
M=```````````````````````````````````````````````````````````
M``````````````````````````````````L````!`````@````````"H`@``
M`````*@"````````'`````````````````````$````````````````````3
M````!P````(`````````R`(```````#(`@```````"``````````````````
M```(````````````````````)@````<````"`````````.@"````````Z`(`
M```````@````````````````````!````````````````````#0````'````
M`@`````````(`P````````@#````````)`````````````````````0`````
M``````````````!+````!0````(`````````,`,````````P`P```````)@"
M````````!P`````````(``````````0`````````1P```/;__V\"````````
M`,@%````````R`4```````#\``````````<`````````"```````````````
M`````%$````+`````@````````#(!@```````,@&````````&`D````````(
M`````0````@`````````&`````````!9`````P````(`````````X`\`````
M``#@#P```````,8$```````````````````!````````````````````80``
M`/___V\"`````````*84````````IA0```````#"``````````<`````````
M`@`````````"`````````&X```#^__]O`@````````!H%0```````&@5````
M````@``````````(`````0````@```````````````````!]````!`````(`
M````````Z!4```````#H%0```````+`!````````!P`````````(````````
M`!@`````````AP````0```!"`````````)@7````````F!<````````H!0``
M``````<````9````"``````````8`````````)$````!````!@````````#`
M'````````,`<````````%P````````````````````0`````````````````
M``",`````0````8`````````X!P```````#@'````````(`#````````````
M```````0`````````!``````````EP````$````&`````````&`@````````
M8"`````````(````````````````````"``````````(`````````*`````!
M````!@````````!P(````````'`@````````##@``````````````````!``
M``````````````````"F`````0````8`````````?%@```````!\6```````
M``D````````````````````$````````````````````K`````$````"````
M`````(A8````````B%@```````!Z0```````````````````"```````````
M`````````+0````!`````@`````````$F0````````29````````#`$`````
M``````````````0```````````````````#"`````0````(`````````$)H`
M```````0F@```````'`&```````````````````(````````````````````
MS`````X````#`````````*"[````````H*L````````(````````````````
M````"``````````(`````````-@````/`````P````````"HNP```````*BK
M````````"`````````````````````@`````````"`````````#D`````0``
M``,`````````L+L```````"PJP```````!,````````````````````0````
M````````````````\0````8````#`````````,B[````````R*L````````@
M`@````````@`````````"``````````0`````````)L````!`````P``````
M``#HO0```````.BM````````$`(```````````````````@`````````"```
M``````#Z`````0````,``````````,``````````L````````"@`````````
M```````````(``````````````````````$```$```"#`````````"C`````
M````*+`````````(`````````!``````````"````````````````````!T!
M```(`````P````````!`P````````#"P````````:```````````````````
M`"`````````````````````B`0```0```#`````````````````````PL```
M`````#$````````````````````!``````````$``````````0````,`````
M````````````````````8;`````````K`0```````````````````0``````
*````````````````
